@@ -22,4 +22,4 @@ class _Datasource(_Base):
         if model_path is not None:
             self.trainers[key]['model_path'] = model_path
 
-        self.dfl.initiate_project_participants(should_spawn_threads=True)
\ No newline at end of file
+        self.dfl.initiate_project_participants(should_spawn_train=True, ds=self.key)
\ No newline at end of file
